pub fn output_capability(tool_id: &str) -> OutputCapabilityExpand description
Classify a tool by name. session_context is the pseudo-tool used
by the compression pass and is the only summary-producing caller.
pub fn output_capability(tool_id: &str) -> OutputCapabilityClassify a tool by name. session_context is the pseudo-tool used
by the compression pass and is the only summary-producing caller.