pub fn load_or_build(source: &str, content: &str) -> ContextIndexExpand description
Load a cached index for identical content or build and persist one.
pub fn load_or_build(source: &str, content: &str) -> ContextIndexLoad a cached index for identical content or build and persist one.