pub struct ContextTrace { /* private fields */ }Expand description
Context trace for a single RLM analysis run.
Implementations
Sourceimpl ContextTrace
impl ContextTrace
Sourcepub fn estimate_tokens(text: &str) -> usize
pub fn estimate_tokens(text: &str) -> usize
Estimate token count from text using about four chars per token.
Sourcepub fn event_from_text(event: ContextEvent, text: &str) -> ContextEvent
pub fn event_from_text(event: ContextEvent, text: &str) -> ContextEvent
Create an event from text with automatic token estimation.
Sourceimpl ContextTrace
impl ContextTrace
Sourceimpl ContextTrace
impl ContextTrace
Sourcepub fn next_iteration(&mut self)
pub fn next_iteration(&mut self)
Increment the iteration counter.
Sourcepub fn total_tokens(&self) -> usize
pub fn total_tokens(&self) -> usize
Get the total tokens used.
Sourcepub fn remaining_tokens(&self) -> usize
pub fn remaining_tokens(&self) -> usize
Get the remaining token budget.
Sourcepub fn budget_used_percent(&self) -> f32
pub fn budget_used_percent(&self) -> f32
Get the percentage of budget used.
Sourcepub fn is_over_budget(&self) -> bool
pub fn is_over_budget(&self) -> bool
Check if the budget is exceeded.
Sourceimpl ContextTrace
impl ContextTrace
Sourcepub fn log_event(&mut self, event: ContextEvent)
pub fn log_event(&mut self, event: ContextEvent)
Log a context event.
Sourcepub fn events(&self) -> &VecDeque<ContextEvent>
pub fn events(&self) -> &VecDeque<ContextEvent>
Get all events.
Sourcepub fn events_of_type(&self, label: &str) -> Vec<&ContextEvent>
pub fn events_of_type(&self, label: &str) -> Vec<&ContextEvent>
Get events by type.
Sourceimpl ContextTrace
impl ContextTrace
Sourcepub fn summary(&self) -> ContextTraceSummary
pub fn summary(&self) -> ContextTraceSummary
Get a summary of the trace.