Module model_select

Module model_select 

RLM model selection policy.

Hosts provide providers and score signals; this crate owns the order of precedence for choosing which RLM model reference to try.

Structs

RlmModelChoice
Selected model plus provenance for logging.

Enums

RlmModelPurpose
RLM call surface that needs a model.
RlmModelSource
Source that won model selection.

Constants

RLM_MODEL_ENV
Environment variable that overrides the RLM root model.

Functions

select_rlm_model
Select the model for an RLM call surface.
select_rlm_model_with_env
Select an RLM model with an injected env value for deterministic tests.